@@ -324,7 +324,7 @@ WWW::Xunlei - Perl API For Official Xunlei Remote API.
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -340,14 +340,12 @@ version 0.05
 C<WWW::Xunlei> is a Perl Wrapper of Xunlei Remote Downloader API.
 L<Official Site of Xunlei Remote|http://yuancheng.xunlei.com>
 
-B<This module is now under deveopment. It's not stable.>
-
 =head1 METHODS
 
 =head2 new( $username, $password, [cookie_file=>'/path/to/cookie'])
 
 create a Xunlei client. Load or save Cookies to a plain text file with 
-C<cookie_file> option.
+C<cookie_file> option. The default session expire time is 7 days.
 
 =head2 bind($key, [$name])
 
@@ -359,6 +357,11 @@ Bind a new downloader with a activation code. The new downloader's name can
 List all the downloaders binding with your account. Return a list of
 C<WWW::Xunlei::Downloader> object.
 
+==method list_downloader($name)
+
+Get the downloader of which the name is $name. 
+Return a C<WWW::Xunlei::Downloader> object.
+
 =head1 AUTHOR
 
 Zhu Sheng Li <zshengli@cpan.org>
